Config

Struct Config 

pub struct Config {
    pub max_packet_size: usize,
    pub compression: Compression,
}
Global configuration.

Example

use tcp_handler::config::Config;

let config = Config::default();

Fields

max_packet_size: usize

max_packet_size is the maximum size of a packet in bytes. It is used to limit the size of a packet that can be received or sent.

The default value is 1 << 20.

Example

use tcp_handler::config::Config;

let config = Config {
    max_packet_size: 1 << 10,
    ..Config::default()
};
compression: Compression
Available on crate feature compression only.

compression is the flate2::Compression level when sending packets.

Example

use tcp_handler::config::Config;
use tcp_handler::Compression;

let config = Config {
    compression: Compression::fast(),
    ..Config::default()
};