pub enum StarterError {
InvalidStream(),
InvalidProtocol(ProtocolVariant),
InvalidIdentifier(String),
InvalidVersion(String),
IO(Error),
RSA(Error),
}Expand description
Error when init/start protocol.
Variants
InvalidStream()
[MAGIC_BYTES] isn’t matched. Or the [MAGIC_VERSION] is no longer supported.
Please confirm that you are connected to the correct address.
InvalidProtocol(ProtocolVariant)
Incompatible tcp-handler protocol. The param came from the other side. Please check whether you use the same protocol between client and server.
InvalidIdentifier(String)
Invalid application identifier. The param came from the other side. Please confirm that you are connected to the correct application, or that there are no spelling errors in the server and client identifiers.
InvalidVersion(String)
Invalid application version. The param came from the other side. This is usually caused by the low version of the client application.
IO(Error)
During io bytes.
RSA(Error)
encryption only.During generating/encrypting/decrypting rsa key.